# -*- coding: utf-8 -*-

"""Console script for certo."""

import ssl

import click

from . import certo


@click.command()
@click.argument('address')#, help="address to be used to retrieve the certificate")
@click.option('-p', '--port', default=443, type=click.IntRange(1,65535), help="The port to connect to.")
@click.option('--starttls', is_flag=True, flag_value=True, help="Whether to use starttls on connection.")
@click.option('--debug/--nodebug', is_flag=True, flag_value=False, help="Debug output.")
@click.option('-o', '--output', help="Path to save the certificate to.")
@click.option('--colons/--nocolons', is_flag=True, flag_value=False, help="Whether to output also hashed with colons.")
@click.option('--colors/--nocolors', is_flag=True, flag_value=True, help="Toggles the colored output.")
def do_it(address, port, starttls, debug, output, colons, colors):
    grabber = certo.Certo(debug, colors)
    cert = grabber.get_cert(address, port, starttls)
    if output:
        with open(output, 'w') as f:
            grabber.logger.debug("Opening file %s" % output)
            f.write(ssl.DER_cert_to_PEM_cert(cert))
        grabber.logger.info("The certificate has been saved to %s" % output)
    grabber.compute_fingerprints(cert, colons)

if __name__ == '__main__':
    do_it()
