# -*- encoding: utf-8 -*-
"""
Module to produce colored log output.
"""
# Taken from http://uran198.github.io/en/python/2016/07/12/colorful-python-logging.html
import logging
import colorama
import copy

LOG_COLORS = {
    logging.ERROR: colorama.Fore.RED,
    logging.WARNING: colorama.Fore.YELLOW,
    logging.INFO: colorama.Fore.WHITE,
    logging.DEBUG: colorama.Fore.BLUE,
}


class ColorFormatter(logging.Formatter):
    def format(self, record, *args, **kwargs):
        new_record = copy.copy(record)
        if new_record.levelno in LOG_COLORS:
            new_record.msg= "{color_begin}{message}{color_end}".format(
                message=new_record.msg,
                color_begin=LOG_COLORS[new_record.levelno],
                color_end=colorama.Style.RESET_ALL,
            )
        return super(ColorFormatter, self).format(new_record, *args, **kwargs)
